<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>Tots els fitxers (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
</context>
<context>
    <name>NetUtils</name>
    <message>
        <source>Off</source>
        <translation>Desactivat</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connectat</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicte d&apos;IP</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Es connecta</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>S&apos;obté l&apos;adreça</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>S&apos;autentica</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconnectat</translation>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>Mode d&apos;avió</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>Atura la comunicació sense fil</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Habilitar el mode d&apos;avió inhabilita la xarxa sense fil, el punt d&apos;accés personal i el Bluetooth.</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>Aplicació de servidor intermediari</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Configuració de servidors intermediaris</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipus de servidor intermediari</translation>
    </message>
    <message>
        <source>http</source>
        <translation>http</translation>
    </message>
    <message>
        <source>socks4</source>
        <translation>socks4</translation>
    </message>
    <message>
        <source>socks5</source>
        <translation>socks5</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adreça IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adreça IP no vàlida</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Port no vàlid</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Marqueu «Usa un servidor intermediari» al menú contextual de l&apos;aplicació al llançador després d&apos;haver-lo configurat.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa-ho</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation>Configuració d&apos;una connexió de xarxa d&apos;accés telefònic</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconnecta</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Connecta</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>Afegeix una connexió PPPoE</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Segur que voleu eliminar aquesta configuració?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa-ho</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation>Propietats de la xarxa %1</translation>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>Detalls de xarxa</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>Mostra totes les configuracions de xarxa</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>S&apos;han copiat els detalls.</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Selecciona-ho tot</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>Detecció de xarxa</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA / WPA2 personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 personal</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Sense vincle</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Punt d&apos;accés personal</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>Comparteix la xarxa</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>El meu punt d&apos;accés</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>Edita el punt d&apos;accés</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nom (SSID)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguretat</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa-ho</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation>Configuració compartida</translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation>Dispositiu per compartir el punt d&apos;accés</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation>Si voleu usar el punt d&apos;accés personal, primer desactiveu el mode d&apos;avió i després activeu l&apos;adaptador de xarxa sense fil.</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation>Si voleu usar el punt d&apos;accés personal, desactiveu primer el &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Mode d&apos;avió&lt;/a&gt; i després activeu l&apos;adaptador de xarxa sense fil.</translation>
    </message>
    <message>
        <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
        <translation>Activeu primer &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;l&apos;adaptador de xarxa sense fil&lt;/a&gt; si voleu usar el punt d&apos;accés personal.</translation>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Segur que voleu eliminar aquesta configuració?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa-ho</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation>Propietats de la xarxa %1</translation>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>Servidor intermediari del sistema</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Configuració de servidors intermediaris</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipus de servidor intermediari</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de configuració</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Servidor intermediari d&apos;HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Servidor intermediari d&apos;HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Servidor intermediari d&apos;FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Servidor intermediari de SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignora les configuracions d&apos;intermediari per als amfitrions i dominis anteriors.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa-ho</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation>XPV</translation>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>Connectar, afegir, importar</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconnecta</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Connecta</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>Afegeix una XPV</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importa una XPV</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Error d&apos;importació</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Error del fitxer</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source>VPN Type</source>
        <translation>Tipus d&apos;XPV</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Segur que voleu eliminar aquesta configuració?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporta</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa-ho</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation>Propietats de la xarxa %1</translation>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Connecta, edita la configuració de la xarxa</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Connecteu primer el cable de xarxa.</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconnecta</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Connecta</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Afegiu una connexió de xarxa</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Connecta, edita la configuració de la xarxa</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconnecta</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Connecta</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>Altres xarxes</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation>Desactiveu primer el mode d&apos;avió si voleu connectar-vos a una xarxa sense fil.</translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Desactiveu primer el &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Mode d&apos;avió&lt;/a&gt; si voleu connectar-vos a una xarxa sense fil.</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Inhabiliteu primer el punt d&apos;accés si voleu connectar-vos a una xarxa sense fil.</translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Inhabiliteu primer el punt d&apos;accés&lt;/a&gt; si voleu connectar-vos a una xarxa sense fil.</translation>
    </message>
    <message>
        <source>My Networks</source>
        <translation>Les meves xarxes</translation>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fet</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adreça IP no vàlida</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation>Sense vincle</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adreça MAC del dispositiu</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Adreça MAC clonada</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalitzeu l&apos;MTU</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation>MTU (1280-9000)</translation>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nom (SSID)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Connexió automàtica</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fet</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inhabilitat</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Mètode</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Només s&apos;aplica als recursos corresponents</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adreça IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adreça IP no vàlida</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Màscara de xarxa</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Màscara de xarxa no vàlida</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passarel·la no vàlida</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Adreça IP duplicada</translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>Inhabilitat</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fet</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Mètode</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Només s&apos;aplica als recursos corresponents</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adreça IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adreça IP no vàlida</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Màscara de xarxa no vàlida</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Adreça IP duplicada</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passarel·la no vàlida</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usa MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE de 128 bits</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE amb estat</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Rebutja l&apos;autenticació d&apos;EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Rebutja l&apos;autenticació de PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Rebutja l&apos;autenticació de CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Rebutja l&apos;autenticació MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Rebutja l&apos;autenticació d&apos;MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sense compressió de dades de BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sense compressió de dades amb deflació</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sense compressió de capçalera TCP</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Envia paquets PPP Echo</translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Servei</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>Seguretat</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS per túnel</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP protegit</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA / WPA2 personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA / WPA2 d&apos;empresa</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 personal</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Autenticació d&apos;EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identitat</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcions de la contrasenya</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Desa la contrasenya per a aquest usuari.</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Desa la contrasenya per a tots els usuaris.</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Pregunta-m&apos;ho sempre.</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Clau</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Contrasenya privada</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticació</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Clau compartida</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Obre el sistema</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clau privada</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID anònim</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Aprovisionament</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inhabilitat</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anònim</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autenticat</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Ambdós</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Fitxer PAC</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificat CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificat d&apos;usuari</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Versió de PEAP</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versió 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versió 1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Autenticació interna</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation>XPV</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Tots els fitxers (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passarel·la no vàlida</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificat CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Servidor intermediari</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Permet Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Script CSD</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipus d&apos;autenticació</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clau privada</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Agent d&apos;SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Targeta intel·ligent</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Clau precompartida</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificat d&apos;usuari</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Usa FSID per a la contrasenya</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificats (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificats amb contrasenya (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Clau estàtica</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcions de la contrasenya</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>S&apos;ha desat</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>No cal</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Contrasenya privada</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personalitzeu la direcció de la clau</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Direcció de la clau</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP remota</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP local</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Domini d&apos;NT</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Demana una adreça IP interna</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Força l&apos;encapsulació d&apos;UPD</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Usa la compressió d&apos;IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Activa les propostes personalitzades d&apos;encriptació</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nom del grup</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Contrasenya del grup</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Usa l&apos;autenticació híbrida</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Fitxer de CA</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>XPV PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usa MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguretat</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Tot el disponible (per defecte)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40 bits (menys segur)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128 bits (més segur)</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE amb estat</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Rebutja l&apos;autenticació d&apos;EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Rebutja l&apos;autenticació de PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Rebutja l&apos;autenticació de CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Rebutja l&apos;autenticació MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Rebutja l&apos;autenticació d&apos;MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sense compressió de dades de BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sense compressió de dades amb deflació</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sense compressió de capçalera TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Sense compressió de camp de protocol</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Sense compressió d&apos;adreça / control</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Envia paquets PPP Echo</translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation>XPV IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Activa l&apos;IPsec</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID del grup</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritmes de fase 1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritmes de fase 2</translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation>XPV avançada</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Personalitzeu el port de la passarel·la</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Port de la passarel·la</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Personalitzeu l&apos;interval de renegociació</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Interval de renegociació</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Usa compressió de dades LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Usa una connexió TCP.</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Usa un dispositiu TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Personalitzeu el túnel d&apos;MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Personalitzeu la mida de fragment d&apos;UPD</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Mida de fragment d&apos;UPD</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Restringeix el túnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Fes aleatoris els amfitrions remots</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domini</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Proveïdor</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (per defecte)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versió</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Encriptació</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Segura (per defecte)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Dèbil</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Mode Traversal de NAT</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T quan estigui disponible (per defecte)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T sempre</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inhabilitat</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Grup IKE DH</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>Grup DH  1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>Grup DH 2 (per defecte)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>Grup DH 5</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Secretisme de reenviament</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Servidor (per defecte)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>Grup DH 2</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Port local</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Inhabilita la detecció de màquines mortes.</translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation>Seguretat de la XPV</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Encripta</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Per defecte</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Autenticació HMAC</translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation>RSA MD-4</translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation>MD-5</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation>SHA-224</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation>SHA-384</translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation>SHA-512</translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation>RIPEMD-160</translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation>Servidor intermediari d&apos;XPV</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipus de servidor intermediari</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP del servidor</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Torna a intentar-ho indefinidament quan falli.</translation>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Autenticació d&apos;XPV TLS</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Coincidència d&apos;assumpte</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Tipus de certificat remot</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Fitxer de clau</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation>MTU (1280-9000)</translation>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation>Cal autenticació</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Desactiveu primer el &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;mode d&apos;avió&lt;/a&gt; si voleu fer una connexió amb una xarxa sense fil.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>Conflicte d&apos;IP</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>Connexió amb fil %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>XPV L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>XPV PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>XPV VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>XPV OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>XPV StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>XPV OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Connexió PPPoE %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>Es connecta amb %1</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>%1 connectat</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>%s desconnectat</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>No es pot connectar amb %1. Comproveu l&apos;encaminador o el cable de xarxa.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>No es pot connectar amb %1. Si us plau, mantingueu-vos a prop de l&apos;encaminador.</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>Ha fallat la connexió. No es pot connectar amb %1: contrasenya incorrecta.</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>Cal la contrasenya per connectar amb %1.</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>No s&apos;ha pogut trobar la xarxa WLAN 802.11 %1.</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>Per connectar amb %1, configureu la informació d&apos;autenticació després d&apos;iniciar sessió.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>Servidor intermediari del sistema</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>La configuració de la XPV no està connectada o no s&apos;ha pogut connectar. Si us plau, &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt; aneu al centre de control&lt;/a&gt; per inspeccionar-ho.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Xarxa amb fil</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Xarxa sense fil</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Connecta amb una xarxa oculta</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Les meves xarxes</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Altres xarxes</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
</context>
<context>
    <name>networkMain</name>
    <message>
        <source>Connection settings</source>
        <translation>Configuració de la connexió</translation>
    </message>
    <message>
        <source>Related Settings</source>
        <translation>Paràmetres relacionats</translation>
    </message>
</context>
</TS>